@@ -14,6 +14,7 @@
 #  limitations under the License.
 
 import pkg_resources
+from blockdiag.utils import Box
 from blockdiag.utils.XY import XY
 from blockdiag.utils import images
 
@@ -51,33 +52,33 @@ def get(shape):
 
 
 class NodeShape(object):
-    def __init__(self, node, metrix=None):
+    def __init__(self, node, metrics=None):
         self.node = node
-        self.metrix = metrix
+        self.metrics = metrics
 
-        m = self.metrix.cell(self.node)
+        m = self.metrics.cell(self.node)
         self.textalign = 'center'
-        self.connectors = [m.top(), m.right(), m.bottom(), m.left()]
+        self.connectors = [m.top, m.right, m.bottom, m.left]
 
         if node.icon is None:
             self.iconbox = None
-            self.textbox = m.box()
+            self.textbox = m.box
         else:
             image_size = images.get_image_size(node.icon)
             if image_size is None:
                 iconsize = (0, 0)
             else:
-                boundedbox = [metrix.nodeWidth / 2, metrix.nodeHeight]
+                boundedbox = [metrics.node_width / 2, metrics.node_height]
                 iconsize = images.calc_image_size(image_size, boundedbox)
 
-            vmargin = (metrix.nodeHeight - iconsize[1]) / 2
-            self.iconbox = (m.topLeft().x,
-                            m.topLeft().y + vmargin,
-                            m.topLeft().x + iconsize[0],
-                            m.topLeft().y + vmargin + iconsize[1])
+            vmargin = (metrics.node_height - iconsize[1]) / 2
+            self.iconbox = (m.topleft.x,
+                            m.topleft.y + vmargin,
+                            m.topleft.x + iconsize[0],
+                            m.topleft.y + vmargin + iconsize[1])
 
-            self.textbox = (self.iconbox[2], m.top().y,
-                            m.bottomRight().x, m.bottomRight().y)
+            self.textbox = (self.iconbox[2], m.top.y,
+                            m.bottomright.x, m.bottomright.y)
 
     def render(self, drawer, format, **kwargs):
         if self.node.stacked and not kwargs.get('stacked'):
@@ -85,10 +86,10 @@ class NodeShape(object):
             node.label = ""
             node.background = ""
             for i in range(2, 0, -1):
-                r = self.metrix.cellSize / 2 * i
-                metrix = self.metrix.shiftedMetrix(r, 0, 0, r)
+                r = self.metrics.cellsize / 2 * i
+                metrics = self.metrics.shiftedMetrics(r, 0, 0, r)
 
-                self.__class__(node, metrix).render(drawer, format,
+                self.__class__(node, metrics).render(drawer, format,
                                                     stacked=True, **kwargs)
 
         if hasattr(self, 'render_vector_shape') and format == 'SVG':
@@ -113,8 +114,8 @@ class NodeShape(object):
         if not kwargs.get('shadow'):
             drawer.textarea(self.textbox, self.node.label,
                             fill=self.node.textcolor, halign=self.textalign,
-                            font=font, fontsize=self.metrix.fontSize,
-                            lineSpacing=self.metrix.lineSpacing)
+                            font=font, fontsize=self.metrics.fontsize,
+                            line_spacing=self.metrics.line_spacing)
 
     def render_number_badge(self, drawer, **kwargs):
         if self.node.numbered != None and kwargs.get('shadow') != True:
@@ -122,35 +123,39 @@ class NodeShape(object):
             outline = kwargs.get('outline')
             badgeFill = kwargs.get('badgeFill')
 
-            xy = self.metrix.cell(self.node).topLeft()
-            r = self.metrix.cellSize * 3 / 2
+            xy = self.metrics.cell(self.node).topleft
+            r = self.metrics.cellsize * 3 / 2
 
             box = (xy.x - r, xy.y - r, xy.x + r, xy.y + r)
             drawer.ellipse(box, outline=outline, fill=badgeFill)
             drawer.textarea(box, self.node.numbered, fill=self.node.textcolor,
-                            font=font, fontsize=self.metrix.fontSize)
+                            font=font, fontsize=self.metrics.fontsize)
 
+    @property
     def top(self):
         return self.connectors[0]
 
+    @property
     def left(self):
         return self.connectors[3]
 
+    @property
     def right(self):
         point = self.connectors[1]
         if self.node.stacked:
-            point = XY(point.x + self.metrix.cellSize, point.y)
+            point = XY(point.x + self.metrics.cellsize, point.y)
         return point
 
+    @property
     def bottom(self):
         point = self.connectors[2]
         if self.node.stacked:
-            point = XY(point.x, point.y + self.metrix.cellSize)
+            point = XY(point.x, point.y + self.metrics.cellsize)
         return point
 
     def shift_shadow(self, value):
-        xdiff = self.metrix.shadowOffsetX
-        ydiff = self.metrix.shadowOffsetY
+        xdiff = self.metrics.shadow_offset.x
+        ydiff = self.metrics.shadow_offset.y
 
         if isinstance(value, XY):
             ret = XY(value.x + xdiff, value.y + ydiff)
@@ -164,5 +169,8 @@ class NodeShape(object):
                         ret.append(x + xdiff)
                     else:
                         ret.append(x + ydiff)
+        elif isinstance(value, Box):
+            ret = Box(value.x1 + xdiff, value.y1 + ydiff,
+                      value.x2 + xdiff, value.y2 + ydiff)
 
         return ret
