@@ -20,13 +20,13 @@ from blockdiag.imagedraw.simplesvg import pathdata
 
 
 class Database(NodeShape):
-    def __init__(self, node, metrix=None):
-        super(Database, self).__init__(node, metrix)
+    def __init__(self, node, metrics=None):
+        super(Database, self).__init__(node, metrics)
 
-        m = self.metrix.cell(self.node)
-        r = self.metrix.cellSize
-        self.textbox = (m.topLeft().x, m.topLeft().y + r * 3 / 2,
-                        m.bottomRight().x, m.bottomRight().y - r / 2)
+        m = self.metrics.cell(self.node)
+        r = self.metrics.cellsize
+        self.textbox = (m.topleft.x, m.topleft.y + r * 3 / 2,
+                        m.bottomright.x, m.bottomright.y - r / 2)
 
     def render_shape(self, drawer, format, **kwargs):
         outline = kwargs.get('outline')
@@ -43,9 +43,9 @@ class Database(NodeShape):
         outline = kwargs.get('outline')
         fill = kwargs.get('fill')
 
-        m = self.metrix.cell(self.node)
-        r = self.metrix.cellSize
-        box = m.box()
+        m = self.metrics.cell(self.node)
+        r = self.metrics.cellsize
+        box = m.box
 
         ellipse = (box[0], box[3] - r * 2, box[2], box[3])
         if kwargs.get('shadow'):
@@ -85,11 +85,11 @@ class Database(NodeShape):
         outline = kwargs.get('outline')
         fill = kwargs.get('fill')
 
-        m = self.metrix.cell(self.node)
-        r = self.metrix.cellSize
-        width = self.metrix.nodeWidth
+        m = self.metrics.cell(self.node)
+        r = self.metrics.cellsize
+        width = self.metrics.node_width
 
-        box = m.box()
+        box = m.box
         if kwargs.get('shadow'):
             box = self.shift_shadow(box)
 
