@@ -20,9 +20,7 @@ from blockdiag.utils.XY import XY
 
 class TextBox(NodeShape):
     def render_shape(self, drawer, format, **kwargs):
-        if kwargs.get('shadow') and self.node.background:
-            box = self.metrix.cell(self.node).box()
-            drawer.loadImage(self.node.background, self.textbox)
+        pass
 
 
 def setup(self):
