@@ -13,4 +13,20 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from postmortem import postmortem
+
+class Box(list):
+    mapper = dict(x1=0, y1=1, x2=2, y2=3)
+
+    def __init__(self, x1, y1, x2, y2):
+        return super(Box, self).__init__((x1, y1, x2, y2))
+
+    def __getattr__(self, name):
+        return self[self.mapper[name]]
+
+    @property
+    def width(self):
+        return self.x2 - self.x1
+
+    @property
+    def height(self):
+        return self.y2 - self.y1
